@@ -14,7 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import nvp
+import helpers
 
 Connection = nvp.Connection
+h = helpers
 
-__all__ = ["Connection"]
+__all__ = ["Connection", "helpers"]
